pub struct FeatureReceipt {
pub feature_id: Id,
pub worker_run_id: Id,
pub candidate_commit: GitObject,
pub independent_validation_attempt: Id,
}Expand description
Identifies an independently accepted feature without importing its worker report. The stage driver resolves these from existing engine events.
Fields
feature_id: Idworker_run_id: Idcandidate_commit: GitObjectindependent_validation_attempt: IdTrait Implementations
Sourceimpl Clone for FeatureReceipt
impl Clone for FeatureReceipt
Sourceimpl Debug for FeatureReceipt
impl Debug for FeatureReceipt