pub struct StandardsMergeEvidence {
pub passed: BTreeSet<String>,
/* private fields */
}Expand description
Positive final evidence that may be consumed by merge-only checker forms. Deterministic gates are always re-run against the scratch integration; only an exact human waiver may permit one of those current failures.
Fields
passed: BTreeSet<String>Implementations
Sourceimpl StandardsMergeEvidence
impl StandardsMergeEvidence
pub fn from_mission_events( mission_id: &str, pin: Option<&StandardsPin>, coverage: Option<&StandardsCoverage>, events: &[Event], now: DateTime<Utc>, ) -> Self