pub struct PinnedRegistration { /* private fields */ }Expand description
Can only be constructed by resolving a trusted ref. Caller authority over the approved ref is a host precondition; this is not an approval API.
Implementations
Sourceimpl PinnedRegistration
impl PinnedRegistration
pub fn checker_files(&self) -> impl Iterator<Item = (&WirePath, &[u8], bool)>
pub fn declaration(&self) -> &Declaration
pub fn bytes(&self) -> &[u8] ⓘ
pub fn digest(&self) -> Digest
pub fn at_ref( repo: &GitRepo, approved_ref: &str, pack_dir: &str, name: &str, ) -> Result<Self, String>